@@ -2,9 +2,12 @@
 # from UNKnownDB.UNDL import Interpreter, APP
 from UNKnownDB.DB import LightDB
 
-
-with LightDB.File('./light') as db:
-    db - 'effectiveness:ef'
+with LightDB.Data('./light') as db:
+    db + 'ed:de'
+    db - 'ed:de'
+    db['fe'] = 'ef0'
+    print(db['fe'])
+    print(db.all())
 with open('./light.unl') as light:
     print(light.read())
 # db = DB.LocalDB("./.Clever.unp")
